@@ -1,15 +1,17 @@
 import sys
 import uuid
 
-import structlog
 import twisted
 
 from twisted.internet import protocol, reactor
 
-logger = structlog.get_logger()
+import structlog
 
 
-class Counter(object):
+logger = structlog.getLogger()
+
+
+class Counter:
     i = 0
 
     def inc(self):
@@ -32,7 +34,7 @@ class Echo(protocol.Protocol):
         self._counter.inc()
         log = self._log.bind(data=data)
         self.transport.write(data)
-        log.msg('echoed data!')
+        log.msg("echoed data!")
 
 
 if __name__ == "__main__":
