@@ -23,25 +23,25 @@ class TestPad:
         assert len("test") == len(dev._pad("test", 2))
 
 
-@pytest.fixture
-def cr():
+@pytest.fixture(name="cr")
+def _cr():
     return dev.ConsoleRenderer(colors=dev._has_colorama)
 
 
-@pytest.fixture
-def styles(cr):
+@pytest.fixture(name="styles")
+def _styles(cr):
     return cr._styles
 
 
-@pytest.fixture
-def padded(styles):
+@pytest.fixture(name="padded")
+def _padded(styles):
     return (
         styles.bright + dev._pad("test", dev._EVENT_WIDTH) + styles.reset + " "
     )
 
 
-@pytest.fixture
-def unpadded(styles):
+@pytest.fixture(name="unpadded")
+def _unpadded(styles):
     return styles.bright + "test" + styles.reset
 
 
@@ -94,16 +94,22 @@ class TestConsoleRenderer:
             None, None, {"event": "test", "level": "critical", "foo": "bar"}
         )
 
-        # fmt: off
         assert (
-            "[" + dev.RED + styles.bright +
-            dev._pad("critical", cr._longest_level) +
-            styles.reset + "] " +
-            padded +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" + styles.reset
+            "["
+            + dev.RED
+            + styles.bright
+            + dev._pad("critical", cr._longest_level)
+            + styles.reset
+            + "] "
+            + padded
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
         ) == rv
-        # fmt: on
 
     def test_init_accepts_overriding_levels(self, styles, padded):
         """
@@ -122,16 +128,22 @@ class TestConsoleRenderer:
             None, None, {"event": "test", "level": "MY_OH_MY", "foo": "bar"}
         )
 
-        # fmt: off
         assert (
-            "[" + dev.RED + styles.bright +
-            dev._pad("MY_OH_MY", cr._longest_level) +
-            styles.reset + "] " +
-            padded +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" + styles.reset
+            "["
+            + dev.RED
+            + styles.bright
+            + dev._pad("MY_OH_MY", cr._longest_level)
+            + styles.reset
+            + "] "
+            + padded
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
         ) == rv
-        # fmt: on
 
     def test_logger_name(self, cr, styles, padded):
         """
@@ -139,14 +151,29 @@ class TestConsoleRenderer:
         """
         rv = cr(None, None, {"event": "test", "logger": "some_module"})
 
-        # fmt: off
         assert (
-            padded +
-            "[" + dev.BLUE + styles.bright +
-            "some_module" +
-            styles.reset + "] "
+            padded
+            + "["
+            + dev.BLUE
+            + styles.bright
+            + "some_module"
+            + styles.reset
+            + "] "
         ) == rv
-        # fmt: on
+
+    def test_logger_name_name(self, cr, padded, styles):
+        """
+        It's possible to set the logger name using a "logger_name" key.
+        """
+        assert (
+            padded
+            + "["
+            + dev.BLUE
+            + styles.bright
+            + "yolo"
+            + styles.reset
+            + "] "
+        ) == cr(None, None, {"event": "test", "logger_name": "yolo"})
 
     def test_key_values(self, cr, styles, padded):
         """
@@ -154,17 +181,24 @@ class TestConsoleRenderer:
         """
         rv = cr(None, None, {"event": "test", "key": "value", "foo": "bar"})
 
-        # fmt: off
         assert (
-            padded +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" +
-            styles.reset + " " +
-            styles.kv_key + "key" + styles.reset + "=" +
-            styles.kv_value + "value" +
-            styles.reset
+            padded
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
+            + " "
+            + styles.kv_key
+            + "key"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "value"
+            + styles.reset
         ) == rv
-        # fmt: on
 
     def test_exception(self, cr, padded):
         """
@@ -193,15 +227,19 @@ class TestConsoleRenderer:
             None, None, {"event": "test", "foo": "bar"}
         )
 
-        # fmt: off
         assert (
-            styles.bright +
-            dev._pad("test", 42) +
-            styles.reset + " " +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" + styles.reset
+            styles.bright
+            + dev._pad("test", 42)
+            + styles.reset
+            + " "
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
         ) == rv
-        # fmt: on
 
     def test_everything(self, cr, styles, padded):
         """
@@ -225,26 +263,46 @@ class TestConsoleRenderer:
             },
         )
 
-        # fmt: off
         assert (
-            styles.timestamp + "13:13" + styles.reset +
-            " [" + styles.level_error + styles.bright +
-            dev._pad("error", cr._longest_level) +
-            styles.reset + "] " +
-            padded +
-            "[" + dev.BLUE + styles.bright +
-            "some_module" +
-            styles.reset + "] " +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" +
-            styles.reset + " " +
-            styles.kv_key + "key" + styles.reset + "=" +
-            styles.kv_value + "value" +
-            styles.reset +
-            "\n" + stack + "\n\n" + "=" * 79 + "\n" +
-            "\n" + exc
+            styles.timestamp
+            + "13:13"
+            + styles.reset
+            + " ["
+            + styles.level_error
+            + styles.bright
+            + dev._pad("error", cr._longest_level)
+            + styles.reset
+            + "] "
+            + padded
+            + "["
+            + dev.BLUE
+            + styles.bright
+            + "some_module"
+            + styles.reset
+            + "] "
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
+            + " "
+            + styles.kv_key
+            + "key"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "value"
+            + styles.reset
+            + "\n"
+            + stack
+            + "\n\n"
+            + "=" * 79
+            + "\n"
+            + "\n"
+            + exc
         ) == rv
-        # fmt: on
 
     def test_colorama_colors_false(self):
         """
@@ -271,16 +329,22 @@ class TestConsoleRenderer:
             None, None, {"event": "test", "level": "critical", "foo": "bar"}
         )
 
-        # fmt: off
         assert (
-            "[" + dev.RED + styles.bright +
-            dev._pad("critical", cr._longest_level) +
-            styles.reset + "] " +
-            padded +
-            styles.kv_key + "foo" + styles.reset + "=" +
-            styles.kv_value + "bar" + styles.reset
+            "["
+            + dev.RED
+            + styles.bright
+            + dev._pad("critical", cr._longest_level)
+            + styles.reset
+            + "] "
+            + padded
+            + styles.kv_key
+            + "foo"
+            + styles.reset
+            + "="
+            + styles.kv_value
+            + "bar"
+            + styles.reset
         ) == rv
-        # fmt: on
 
         assert not dev._has_colorama or dev._ColorfulStyles is cr._styles
 
