@@ -1,17 +1,14 @@
-# -*- coding: utf-8 -*-
-
 # This file is dual licensed under the terms of the Apache License, Version
 # 2.0, and the MIT License.  See the LICENSE file in the root of this
 # repository for complete details.
 
-from __future__ import absolute_import, division, print_function
 
 import datetime
 import json
+import pickle
 import sys
 
 import pytest
-import six
 
 from freezegun import freeze_time
 
@@ -31,21 +28,14 @@ from structlog.processors import (
 )
 from structlog.threadlocal import wrap_dict
 
-from .utils import py3_only
-
 
 try:
     import simplejson
 except ImportError:
     simplejson = None
 
-try:
-    import rapidjson
-except ImportError:
-    rapidjson = None
 
-
-class TestKeyValueRenderer(object):
+class TestKeyValueRenderer:
     def test_sort_keys(self, event_dict):
         """
         Keys are sorted if sort_keys is set.
@@ -132,13 +122,10 @@ class TestKeyValueRenderer(object):
         )
 
         cnt = rv.count("哈")
-        if rns and six.PY2:
-            assert 0 == cnt
-        else:
-            assert 2 == cnt
+        assert 2 == cnt
 
 
-class TestJSONRenderer(object):
+class TestJSONRenderer:
     def test_renders_json(self, event_dict):
         """
         Renders a predictable JSON string.
@@ -205,25 +192,8 @@ class TestJSONRenderer(object):
             "z": [1, 2],
         } == json.loads(jr(None, None, event_dict))
 
-    @pytest.mark.skipif(
-        rapidjson is None, reason="python-rapidjson is missing."
-    )
-    def test_rapidjson(self, event_dict):
-        """
-        Integration test with python-rapidjson.
-        """
-        jr = JSONRenderer(serializer=rapidjson.dumps)
 
-        assert {
-            "a": "<A(\\o/)>",
-            "b": [3, 4],
-            "x": 7,
-            "y": "test",
-            "z": [1, 2],
-        } == json.loads(jr(None, None, event_dict))
-
-
-class TestTimeStamper(object):
+class TestTimeStamper:
     def test_disallows_non_utc_unix_timestamps(self):
         """
         A asking for a UNIX timestamp with a timezone that's not UTC raises a
@@ -285,8 +255,27 @@ class TestTimeStamper(object):
 
         assert "03" == d["month"]
 
+    @freeze_time("1980-03-25 16:00:00")
+    @pytest.mark.parametrize("fmt", [None, "%Y"])
+    @pytest.mark.parametrize("utc", [True, False])
+    @pytest.mark.parametrize("key", [None, "other-key"])
+    @pytest.mark.parametrize("proto", range(pickle.HIGHEST_PROTOCOL))
+    def test_pickle(self, fmt, utc, key, proto):
+        """
+        TimeStamper is serializable.
+        """
+        # UNIX timestamps must be UTC.
+        if fmt is None and not utc:
+            pytest.skip()
 
-class TestFormatExcInfo(object):
+        ts = TimeStamper()
+
+        assert ts(None, None, {}) == pickle.loads(pickle.dumps(ts, proto))(
+            None, None, {}
+        )
+
+
+class TestFormatExcInfo:
     def test_formats_tuple(self, monkeypatch):
         """
         If exc_info is a tuple, it is used.
@@ -314,10 +303,9 @@ class TestFormatExcInfo(object):
         assert "exc_info" not in d
         assert 'raise ValueError("test")\nValueError: test' in d["exception"]
 
-    @py3_only
     def test_exception_on_py3(self, monkeypatch):
         """
-        Passing excetions as exc_info is valid on Python 3.
+        Passing exceptions as exc_info is valid on Python 3.
         """
         monkeypatch.setattr(
             structlog.processors,
@@ -328,11 +316,11 @@ class TestFormatExcInfo(object):
             raise ValueError("test")
         except ValueError as e:
             d = format_exc_info(None, None, {"exc_info": e})
+
             assert {"exception": (ValueError, e, e.__traceback__)} == d
         else:
             pytest.fail("Exception not raised.")
 
-    @py3_only
     def test_exception_without_traceback(self):
         """
         If an Exception is missing a traceback, render it anyway.
@@ -344,14 +332,14 @@ class TestFormatExcInfo(object):
         assert {"exception": "Exception: no traceback!"} == rv
 
 
-class TestUnicodeEncoder(object):
+class TestUnicodeEncoder:
     def test_encodes(self):
         """
         Unicode strings get encoded (as UTF-8 by default).
         """
         ue = UnicodeEncoder()
 
-        assert {"foo": b"b\xc3\xa4r"} == ue(None, None, {"foo": u"b\xe4r"})
+        assert {"foo": b"b\xc3\xa4r"} == ue(None, None, {"foo": "b\xe4r"})
 
     def test_passes_arguments(self):
         """
@@ -359,7 +347,7 @@ class TestUnicodeEncoder(object):
         """
         ue = UnicodeEncoder("latin1", "xmlcharrefreplace")
 
-        assert {"foo": b"&#8211;"} == ue(None, None, {"foo": u"\u2013"})
+        assert {"foo": b"&#8211;"} == ue(None, None, {"foo": "\u2013"})
 
     def test_bytes_nop(self):
         """
@@ -370,14 +358,14 @@ class TestUnicodeEncoder(object):
         assert {"foo": b"b\xc3\xa4r"} == ue(None, None, {"foo": b"b\xc3\xa4r"})
 
 
-class TestUnicodeDecoder(object):
+class TestUnicodeDecoder:
     def test_decodes(self):
         """
         Byte strings get decoded (as UTF-8 by default).
         """
         ud = UnicodeDecoder()
 
-        assert {"foo": u"b\xe4r"} == ud(None, None, {"foo": b"b\xc3\xa4r"})
+        assert {"foo": "b\xe4r"} == ud(None, None, {"foo": b"b\xc3\xa4r"})
 
     def test_passes_arguments(self):
         """
@@ -385,7 +373,7 @@ class TestUnicodeDecoder(object):
         """
         ud = UnicodeDecoder("utf-8", "ignore")
 
-        assert {"foo": u""} == ud(None, None, {"foo": b"\xa1\xa4"})
+        assert {"foo": ""} == ud(None, None, {"foo": b"\xa1\xa4"})
 
     def test_bytes_nop(self):
         """
@@ -393,10 +381,10 @@ class TestUnicodeDecoder(object):
         """
         ud = UnicodeDecoder()
 
-        assert {"foo": u"b\u2013r"} == ud(None, None, {"foo": u"b\u2013r"})
+        assert {"foo": "b\u2013r"} == ud(None, None, {"foo": "b\u2013r"})
 
 
-class TestExceptionPrettyPrinter(object):
+class TestExceptionPrettyPrinter:
     def test_stdout_by_default(self):
         """
         If no file is supplied, use stdout.
@@ -488,7 +476,6 @@ class TestExceptionPrettyPrinter(object):
 
         assert "XXX" in sio.getvalue()
 
-    @py3_only
     def test_exception_on_py3(self, sio):
         """
         On Python 3, it's also legal to pass an Exception.
@@ -507,7 +494,7 @@ def sir():
     return StackInfoRenderer()
 
 
-class TestStackInfoRenderer(object):
+class TestStackInfoRenderer:
     def test_removes_stack_info(self, sir):
         """
         The `stack_info` key is removed from `event_dict`.
@@ -530,7 +517,7 @@ class TestStackInfoRenderer(object):
         assert 'ed = sir(None, None, {"stack_info": True})' in ed["stack"]
 
 
-class TestFigureOutExcInfo(object):
+class TestFigureOutExcInfo:
     @pytest.mark.parametrize("true_value", [True, 1, 1.1])
     def test_obtains_exc_info_on_True(self, true_value):
         """
@@ -543,7 +530,6 @@ class TestFigureOutExcInfo(object):
         else:
             pytest.fail("Exception not raised.")
 
-    @py3_only
     def test_py3_exception_no_traceback(self):
         """
         Exceptions without tracebacks are simply returned with None for
